Package: HDTD
Type: Package
Title: Statistical Inference about the Mean Matrix and the Covariance
        Matrices in High-Dimensional Transposable Data (HDTD)
Version: 1.44.0
Authors@R: c(
    person(given = "Anestis",
           family = "Touloumis",
           email = "A.Touloumis@brighton.ac.uk",
           role = c("cre","aut"),
           comment = c(ORCID = "0000-0002-5965-1639")),
    person(given = "John C.",
           family = "Marioni",
           role = "aut",
           comment = c(ORCID = "0000-0001-9092-0852")),
    person(given = "Simon",
           family = "Tavar\\'{e}",
           role = "aut",
           comment = c(ORCID = "0000-0002-3716-4952"))
           )
Depends: R (>= 4.1)
Suggests: knitr, rmarkdown
Imports: stats, Rcpp (>= 1.0.1)
LinkingTo: Rcpp, RcppArmadillo
Description: Characterization of intra-individual variability using physiologically relevant measurements provides important insights into fundamental biological questions ranging from cell type identity to tumor development. For each individual, the data measurements can be written as a matrix with the different subsamples of the individual recorded in the columns and the different phenotypic units recorded in the rows. Datasets of this type are called high-dimensional transposable data. The HDTD package provides functions for conducting statistical inference for the mean relationship between the row and column variables and for the covariance structure within and between the row and column variables.
License: GPL-3
biocViews: DifferentialExpression, Genetics, GeneExpression,
        Microarray, Sequencing, StatisticalMethod, Software
VignetteBuilder: knitr
URL: http://github.com/AnestisTouloumis/HDTD
BugReports: http://github.com/AnestisTouloumis/HDTD/issues
LazyData: false
NeedsCompilation: yes
RoxygenNote: 7.1.1
Encoding: UTF-8
git_url: https://git.bioconductor.org/packages/HDTD
git_branch: RELEASE_3_22
git_last_commit: b83dbae
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
Packaged: 2025-10-30 04:24:43 UTC; biocbuild
Author: Anestis Touloumis [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-5965-1639>),
  John C. Marioni [aut] (ORCID: <https://orcid.org/0000-0001-9092-0852>),
  Simon Tavar\'{e} [aut] (ORCID: <https://orcid.org/0000-0002-3716-4952>)
Maintainer: Anestis Touloumis <A.Touloumis@brighton.ac.uk>
