# Generated by roxygen2: do not edit by hand

S3method(print,covmat.hat)
S3method(print,covmat.ts)
S3method(print,meanmat.hat)
S3method(print,meanmat.ts)
export(centerdata)
export(covmat.hat)
export(covmat.ts)
export(meanmat.hat)
export(meanmat.ts)
export(orderdata)
export(transposedata)
import(Rcpp)
importFrom(stats,na.omit)
importFrom(stats,pnorm)
useDynLib(HDTD, .registration = TRUE)
