# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

pmat <- function(x) {
    .Call(`_HDTD_pmat`, x)
}

projectionmatrix <- function(x) {
    .Call(`_HDTD_projectionmatrix`, x)
}

sumdatamatrix <- function(X, N) {
    .Call(`_HDTD_sumdatamatrix`, X, N)
}

centerdatamatrix <- function(X, N) {
    .Call(`_HDTD_centerdatamatrix`, X, N)
}

transposedatamatrix <- function(X, N) {
    .Call(`_HDTD_transposedatamatrix`, X, N)
}

tcrossprodcpp <- function(X) {
    .Call(`_HDTD_tcrossprodcpp`, X)
}

tcrossprod2cpp <- function(X, Y) {
    .Call(`_HDTD_tcrossprod2cpp`, X, Y)
}

crossprodcpp <- function(X) {
    .Call(`_HDTD_crossprodcpp`, X)
}

crossprod2cpp <- function(X, Y) {
    .Call(`_HDTD_crossprod2cpp`, X, Y)
}

sampleSigmaR <- function(X, N) {
    .Call(`_HDTD_sampleSigmaR`, X, N)
}

statistics_centered <- function(X, N) {
    .Call(`_HDTD_statistics_centered`, X, N)
}

statistics_trans_centered <- function(X, N) {
    .Call(`_HDTD_statistics_trans_centered`, X, N)
}

statistics <- function(X, N) {
    .Call(`_HDTD_statistics`, X, N)
}

statistics_trans <- function(X, N) {
    .Call(`_HDTD_statistics_trans`, X, N)
}

covmathat_statistics_centered <- function(X, N) {
    .Call(`_HDTD_covmathat_statistics_centered`, X, N)
}

covmathat_statistics_trans_centered <- function(X, N) {
    .Call(`_HDTD_covmathat_statistics_trans_centered`, X, N)
}

covmathat_statistics <- function(X, N) {
    .Call(`_HDTD_covmathat_statistics`, X, N)
}

covmathat_statistics_trans <- function(X, N) {
    .Call(`_HDTD_covmathat_statistics_trans`, X, N)
}

meanmatts_statistics <- function(X, N) {
    .Call(`_HDTD_meanmatts_statistics`, X, N)
}

